@@ -451,7 +451,7 @@ def create_title_and_route(method, extra_radii, opt=True, freq=True, ecp=False,
         routecard += "empiricaldispersion=gd3 int=grid=ultrafine "
 
     if chelpg == 'charge':
-        routecard += "pop=(CHELPG, Atom"
+        routecard += "pop=(CHELPG"
     elif chelpg == 'charge_dipole':
         routecard += "pop=(CHELPG, AtomDipole"
 
@@ -668,7 +668,7 @@ def create_com_file(charge, mult, f_name_head, labels, coords,
 
 def gen_input(f_name: str, labels: list[str], coords: ArrayLike,
               charge: int, mult: int, method: str, bs_spec: dict[str: str],
-              ecp_spec: dict[str:str], subiso: list[int, float],
+              ecp_spec: dict[str:str], subiso: list[int, float] = [],
               chelpg: str = '', opt: bool = True, freq: bool = True,
               extra_route: list[str] = [], extra_title: str = "",
               verbose: bool = True, frozen: list[str] = []):
